@@ -130,40 +130,45 @@ class XObject(object):
         return self.bind(name, lambda x: x(*args, **kwargs))
 
     def __eq__(self, other):
-        return self.bind('X == %s' % other, lambda x: x == other)
+        return self.bind(u'X == {0}'.format(other), lambda x: x == other)
 
     def __getattr__(self, name):
-        return self.bind('X.%s' % name, lambda x: getattr(x, name))
+        return self.bind(u'X.{0}'.format(name), lambda x: getattr(x, name))
 
     def __getitem__(self, item):
-        return self.bind('X[%s]' % item, lambda x: x[item])
+        return self.bind(u'X[{0}]'.format(item), lambda x: x[item])
 
     def __gt__(self, other):
-        return self.bind('X > %s' % other, lambda x: x > other)
+        return self.bind(u'X > {0}'.format(other), lambda x: x > other)
 
     def __lt__(self, other):
-        return self.bind('X < %s' % other, lambda x: x < other)
+        return self.bind(u'X < {0}'.format(other), lambda x: x < other)
 
     def __mod__(self, y):
-        return self.bind('X %% %s' % y, lambda x: x % y)
+        return self.bind(u'X % {0}'.format(y), lambda x: x % y)
 
     def __ne__(self, other):
-        return self.bind('X != %s' % other, lambda x: x != other)
+        return self.bind(u'X != {0}'.format(other), lambda x: x != other)
 
     def __neg__(self):
         return self.bind('-X', lambda x: -x)
 
     def __mul__(self, other):
-        return self.bind('X * %s' % other, lambda x: x * other)
+        return self.bind(u'X * {0}'.format(other), lambda x: x * other)
 
     def __add__(self, other):
-        return self.bind('X + %s' % other, lambda x: x + other)
+        return self.bind(u'X + {0}'.format(other), lambda x: x + other)
 
     def __ror__(self, func):
         return pipe | func | self
 
-    def _in_(self, container):
-        return self.bind('X._in_(%s)' % container, lambda x: x in container)
+    def __or__(self, func):
+        if isinstance(func, Pipe):
+            return func.__ror__(self)
+        return pipe | self | func
+
+    def _in_(self, y):
+        return self.bind(u'X._in_({0})'.format(y), lambda x: x in y)
 
 
 X = XObject()
